<?php

/**
* @file
* Contains \Drupal\sscwidget\Form\SSCWidgetForm.
**/

namespace Drupal\sscwidget\Form;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class SSCWidgetForm extends ConfigFormBase {

    public function getFormId() {
	return 'sscwidget_form';
    }

    public function buildForm(array $form, FormStateInterface $form_state) {
	$form['items_type'] = array(
	    '#type' => 'select',
	    '#options' => array(
		'conferences' => 'Conferences, Symposia, Seminars',
		'grants' => 'Scholarships, Grants and Contests',
		'vacancies' => 'Vacancies',
	    ),
	    '#required' => TRUE,
	    '#empty_option' => '-- please select --',
	    '#title' => $this->t('Select opportunity type to display in widget'),
	    '#default_value' => $this->config('sscwidget.sscconf')->get('items_type'),
	);
	$form['grants_type'] = array(
	    '#type' => 'select',
	    '#options' => array(
		'all' => t('Display all types'),
		'For studying abroad' => t('Scholarships for studying abroad'),
		'Joint research project' => t('Joint research projects'),
		'For scientific researches' => t('Grants for conducting research'),
		'Summer school' => t('Summer schools'),
		'Internship' => t('Internships'),
		'Educational contest' => t('Educational contests'),
		'Art contest' => t('Art contests'),
		'Social contest' => t('Social contests'),
	    ),
	    '#states' => ['visible' => [
			    'select[name="items_type"]' => ['value' => 'grants'],
			]],
	    '#title' => $this->t('Type of grants to be displayed'),
	    '#default_value' => null !== $this->config('sscwidget.sscconf')->get('grants_type') ? $this->config('sscwidget.sscconf')->get('grants_type') : 'all',
	);
	$form['vacancies_area'] = array(
	    '#type' => 'select',
	    '#options' => array(
		'all' => t('Display vacancies from all areas'),
		'for physicists' => t('Vacancies for physicists'),
		'for chemists' => t('Vacancies for chemists'),
		'for mathematicians' => t('Vacancies for mathematicians'),
		'technical specialties' => t('Vacancies technical specialties'),
		'for economists' => t('Vacancies for economists'),
		'for lawyers' => t('Vacancies for lawyers'),
		'for humanities' => t('Vacancies for humanities'),
		'for biologists' => t('Vacancies for biologists'),
		'for physicians and pharmacists' => t('Vacancies for physicians and pharmacists'),
		'for historians' => t('Vacancies for historians'),
		'for surveyors' => t('Vacancies for surveyors'),
		'for ecologists' => t('Vacancies for ecologists'),
	    ),
	    '#states' => ['visible' => [
			    'select[name="items_type"]' => ['value' => 'vacancies'],
			]],
	    '#title' => $this->t('Vacancies from which area to display?'),
	    '#default_value' => null !== $this->config('sscwidget.sscconf')->get('vacancies_area') ? $this->config('sscwidget.sscconf')->get('vacancies_area') : 'all',
	);
	$form['conferences_area'] = array(
	    '#type' => 'select',
	    '#options' => array(
		'all' => t('Display conferences from all areas'),
		'Ecology' => t('Ecology'),
		'Nanotech' => t('Nanotech'),
		'Physics and math' => t('Physics and math'),
		'Chemistry' => t('Chemistry'),
		'Biology' => t('Biology'),
		'Geology and mineralogy' => t('Geology and mineralogy'),
		'Technical sciences' => t('Technical sciences'),
		'Agricultural' => t('Agricultural'),
		'History and archeology' => t('History and archeology'),
		'Economics and management' => t('Economics and management'),
		'Philosophy' => t('Philosophy'),
		'Humanities' => t('Humanities'),
		'Geography' => t('Geography'),
		'Law' => t('Law'),
		'Pedagogy' => t('Pedagogy'),
		'Medicine' => t('Medicine'),
		'Pharmaceutics' => t('Pharmaceutics'),
		'Veterinary science' => t('Veterinary science'),
		'Arts' => t('Arts'),
		'Architecture' => t('Architecture'),
		'Psychology' => t('Psychology'),
		'Sociology' => t('Sociology'),
		'Political science' => t('Political science'),
		'Cultural science' => t('Cultural science'),
		'Earth sciences' => t('Earth sciences'),
		'Computer science' => t('Computer science'),
	    ),
	    '#states' => ['visible' => [
			    'select[name="items_type"]' => ['value' => 'conferences'],
			]],
	    '#title' => $this->t('Scientific area of conferences'),
	    '#default_value' => null !== $this->config('sscwidget.sscconf')->get('conferences_area') ? $this->config('sscwidget.sscconf')->get('conferences_area') : 'all',
	);
	$form['items_lang'] = array(
	    '#type' => 'select',
	    '#options' => array(
		'en' => 'English',
		'ru' => 'Russian',
		'uk' => 'Ukrainian',
		'all' => 'All languages',
	    ),
	    '#required' => TRUE,
	    '#empty_option' => '-- please select --',
	    '#title' => $this->t('Select language of opportunities to display'),
	    '#default_value' => $this->config('sscwidget.sscconf')->get('items_lang'),
	);
	$form['items_quantity'] = array(
	    '#type' => 'number',
	    '#title' => $this->t('Number of items to display in widget'),
	    '#step' => 1,
	    '#min' => 1,
	    '#max' => 15,
	    '#required' => TRUE,
	    '#default_value' => $this->config('sscwidget.sscconf')->get('items_quantity'),
	);
	return parent::buildForm($form, $form_state);
    }

    public function validateForm(array &$form, FormStateInterface $form_state) {
	if (!$form_state->isValueEmpty('items_quantity')) {
	    if ($form_state->getValue('items_quantity') < 1 || $form_state->getValue('items_quantity') > 15) {
		$form_state->setErrorByName('items_quantity', t('Items quantity should be between 1 and 15!'));
	    }
	} else {
	    $form_state->setErrorByName('items_quantity', t('Items quantity field can\'t be blank!'));
	}
    }

    public function submitForm(array &$form, FormStateInterface $form_state) {
	parent::submitForm($form, $form_state);
	$this->configFactory->getEditable('sscwidget.sscconf')
		->set('items_type', $form_state->getValue('items_type'))
		->set('grants_type', $form_state->getValue('grants_type'))
		->set('vacancies_area', $form_state->getValue('vacancies_area'))
		->set('conferences_area', $form_state->getValue('conferences_area'))
		->set('items_quantity', $form_state->getValue('items_quantity'))
		->set('items_lang', $form_state->getValue('items_lang'))
		->save();
	$datacid = 'sscwidget:data';
	\Drupal::cache()->delete($datacid);
	drupal_set_message(t("Widget cache cleared!"));
    }

    protected function getEditableConfigNames() {
	return ['sscwidget.sscconf'];
    }

}